==> h2gis-1.5.0-sources.jar: org/h2gis/functions/spatial/convert/ST_ToMultiPoint.java <==
/**
 * H2GIS is a library that brings spatial support to the H2 Database Engine
 * <http://www.h2database.com>. H2GIS is developed by CNRS
 * <http://www.cnrs.fr/>.
 *
 * This code is part of the H2GIS project. H2GIS is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation;
 * version 3.0 of the License.
 *
 * H2GIS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details <http://www.gnu.org/licenses/>.
 *
 *
 * For more information, please consult: <http://www.h2gis.org/>
 * or contact directly: info_at_h2gis.org
 */

package org.h2gis.functions.spatial.convert;

import org.h2gis.api.DeterministicScalarFunction;
import org.locationtech.jts.geom.Geometry;
import org.locationtech.jts.geom.GeometryFactory;
import org.locationtech.jts.geom.MultiPoint;

/**
 * ST_ToMultiPoint constructs a MultiPoint from the given geometry's coordinates.
 *
 * @author Adam Gouge
 */
public class ST_ToMultiPoint extends DeterministicScalarFunction {

    private static final GeometryFactory GEOMETRY_FACTORY = new GeometryFactory();

    public ST_ToMultiPoint() {
        addProperty(PROP_REMARKS, "Constructs a MultiPoint from the given geometry's " +
                "coordinates.");
    }

    @Override
    public String getJavaStaticMethod() {
        return "createMultiPoint";
    }

    /**
     * Constructs a MultiPoint from the given geometry's coordinates.
     *
     * @param geom Geometry
     * @return A MultiPoint constructed from the given geometry's coordinates
     */
    public static MultiPoint createMultiPoint(Geometry geom) {
        if (geom != null) {
            return GEOMETRY_FACTORY.createMultiPoint(geom.getCoordinates());
        } else {
            return null;
        }
    }
}

==> h2gis-2.2.0-sources.jar: org/h2gis/functions/spatial/convert/ST_ToMultiPoint.java <==
/**
 * H2GIS is a library that brings spatial support to the H2 Database Engine
 * <a href="http://www.h2database.com">http://www.h2database.com</a>. H2GIS is developed by CNRS
 * <a href="http://www.cnrs.fr/">http://www.cnrs.fr/</a>.
 *
 * This code is part of the H2GIS project. H2GIS is free software; 
 * you can redistribute it and/or modify it under the terms of the GNU
 * Lesser General Public License as published by the Free Software Foundation;
 * version 3.0 of the License.
 *
 * H2GIS is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details <http://www.gnu.org/licenses/>.
 *
 *
 * For more information, please consult: <a href="http://www.h2gis.org/">http://www.h2gis.org/</a>
 * or contact directly: info_at_h2gis.org
 */

package org.h2gis.functions.spatial.convert;

import org.h2gis.api.DeterministicScalarFunction;
import org.locationtech.jts.geom.Geometry;
import org.locationtech.jts.geom.MultiPoint;

/**
 * ST_ToMultiPoint constructs a MultiPoint from the given geometry's coordinates.
 *
 * @author Adam Gouge
 * @author Erwan Bocher, CNRS
 */
public class ST_ToMultiPoint extends DeterministicScalarFunction {


    public ST_ToMultiPoint() {
        addProperty(PROP_REMARKS, "Constructs a MultiPoint from the given geometry's " +
                "coordinates.");
    }

    @Override
    public String getJavaStaticMethod() {
        return "createMultiPoint";
    }

    /**
     * Constructs a MultiPoint from the given geometry's coordinates.
     *
     * @param geom Geometry
     * @return A MultiPoint constructed from the given geometry's coordinates
     */
    public static MultiPoint createMultiPoint(Geometry geom) {
        if (geom != null) {
            return geom.getFactory().createMultiPointFromCoords(geom.getCoordinates());
        } else {
            return null;
        }
    }
}
